# coding: utf-8
from django.db import models

from pyoffers.api import HasOffersAPI

from .settings import ENDPOINT, NETWORK_TOKEN, NETWORK_ID, VERIFY, VERBOSITY


class HasOffersModel(models.Model):
    """
    Basic entity to store on our side. It points to remote HasOffers entity via integer ID.
    """
    hasoffers_id = models.IntegerField(unique=True)

    hasoffers = HasOffersAPI(ENDPOINT, NETWORK_TOKEN, NETWORK_ID, VERIFY, VERBOSITY)

    class Meta:
        abstract = True

    @property
    def instance(self):
        """
        Convenience wrapper for remote instance. Taken from `pyoffers`.
        """
        return self.hasoffers._managers[self.__class__.__name__].find_by_id(self.hasoffers_id)



# coding: utf-8
from django.conf import settings


DEFAULT_CONFIG = {
    'ENDPOINT': 'https://api.hasoffers.com/Apiv3/json',
    'NETWORK_TOKEN': None,
    'NETWORK_ID': None,
    'VERIFY': True,
    'VERBOSITY': 0,
}
config = getattr(settings, 'HASOFFERS', DEFAULT_CONFIG)

ENDPOINT = config.get('ENDPOINT', DEFAULT_CONFIG['ENDPOINT'])
NETWORK_TOKEN = config.get('NETWORK_TOKEN', DEFAULT_CONFIG['NETWORK_TOKEN'])
NETWORK_ID = config.get('NETWORK_ID', DEFAULT_CONFIG['NETWORK_ID'])
VERIFY = config.get('VERIFY', DEFAULT_CONFIG['VERIFY'])
VERBOSITY = config.get('VERBOSITY', DEFAULT_CONFIG['VERBOSITY'])



# coding: utf-8
from setuptools import setup

import djoffers


setup(
    name='djoffers',
    url='https://github.com/Stranger6667/djoffers',
    version=djoffers.__version__,
    packages=['djoffers'],
    license='MIT',
    author='Dmitry Dygalo',
    author_email='dadygalo@gmail.com',
    maintainer='Dmitry Dygalo',
    maintainer_email='dadygalo@gmail.com',
    keywords=['hasoffers', 'django', 'cache'],
    description='Django models for HasOffers',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: Implementation :: CPython',
    ],
    include_package_data=True,
    install_requires=['django>=1.9', 'pyoffers'],
)
